from __future__ import annotations

import sys as sys
import typing as typing

from demo.pure_python.functions_3_8_plus import args_mix

__all__: list[str] = [
    "accept_frozenset",
    "args_mix",
    "builtin_function_as_default_arg",
    "function_as_default_arg",
    "lambda_as_default_arg",
    "search",
    "static_method_as_default_arg",
    "sys",
    "typing",
]

class _Dummy:
    @staticmethod
    def foo(): ...

def accept_frozenset(arg: frozenset[int | float]) -> int | None: ...
def builtin_function_as_default_arg(func: type(len) = len): ...
def function_as_default_arg(func: type(search) = search): ...
def lambda_as_default_arg(callback=...): ...
def search(a: int, b: list[int]) -> int: ...
def static_method_as_default_arg(callback=_Dummy.foo): ...



from __future__ import annotations

import typing

import demo._bindings.classes

__all__: list[str] = ["Bar1"]

class Bar1:
    foo: typing.ClassVar[
        demo._bindings.classes.Foo
    ]  # value = <demo._bindings.classes.Foo object>



from __future__ import annotations

import typing

import numpy
import typing_extensions

__all__: list[str] = [
    "accept_ndarray_float64",
    "accept_ndarray_int",
    "get_ndarray_float64",
    "get_ndarray_int",
    "return_dtype",
]

def accept_ndarray_float64(
    arg0: typing_extensions.Annotated[numpy.ndarray, numpy.float64]
) -> None: ...
def accept_ndarray_int(
    arg0: typing_extensions.Annotated[numpy.ndarray, numpy.int32]
) -> None: ...
def get_ndarray_float64() -> typing_extensions.Annotated[
    numpy.ndarray, numpy.float64
]: ...
def get_ndarray_int() -> typing_extensions.Annotated[numpy.ndarray, numpy.int32]: ...
def return_dtype() -> numpy.dtype[typing.Any]: ...



from __future__ import annotations

from . import classes, functions, functions_3_8_plus, functions_3_9_plus, values

__all__: list[str] = [
    "classes",
    "functions",
    "functions_3_8_plus",
    "functions_3_9_plus",
    "values",
]



from __future__ import annotations

import typing

__all__: list[str] = [
    "Foo",
    "accept_callable",
    "accept_frozenset",
    "accept_py_handle",
    "accept_py_object",
    "accept_set",
    "add",
    "default_custom_arg",
    "default_int_arg",
    "default_list_arg",
    "default_optional_arg",
    "func_w_anon_args",
    "func_w_named_pos_args",
    "generic",
    "mul",
    "pass_callback",
    "pos_kw_only_mix",
    "pos_kw_only_variadic_mix",
]

class Foo:
    def __init__(self, arg0: int) -> None: ...

def accept_callable(arg0: typing.Callable) -> typing.Any: ...
def accept_frozenset(arg0: frozenset) -> None: ...
def accept_py_handle(arg0: typing.Any) -> str: ...
def accept_py_object(arg0: typing.Any) -> str: ...
def accept_set(arg0: set) -> None: ...
def add(arg0: int, arg1: int) -> int: ...
def default_custom_arg(foo: Foo = Foo(5)) -> None: ...
def default_int_arg(n: int = 5) -> None: ...
def default_list_arg(l: list = [1, 2, 6, 18]) -> None: ...
def default_optional_arg(n: int | None = None) -> None: ...
def func_w_anon_args(arg0: int, arg1: int, arg2: int) -> None: ...
def func_w_named_pos_args(x: int, y: int, z: int) -> None: ...
def generic(*args, **kwargs) -> None: ...
@typing.overload
def mul(x: int, y: int) -> int:
    """
    Multiply x and y (int)
    """

@typing.overload
def mul(p: float, q: float) -> float:
    """
    Multiply p and q (double)
    """

def pass_callback(arg0: typing.Callable[[Foo], Foo]) -> Foo: ...
def pos_kw_only_mix(i: int, /, j: int, *, k: int) -> tuple: ...
def pos_kw_only_variadic_mix(i: int, /, j: int, *args, k: int, **kwargs) -> tuple: ...



from __future__ import annotations

import typing

import pybind11_stubgen.typing_ext

__all__: list[str] = [
    "std_array",
    "std_map",
    "std_optional",
    "std_variant",
    "std_vector",
]

def std_array(
    arg0: typing.Annotated[list[int], pybind11_stubgen.typing_ext.FixedSize(3)]
) -> typing.Annotated[list[int], pybind11_stubgen.typing_ext.FixedSize(3)]: ...
def std_map() -> dict[int, complex]: ...
def std_optional(arg0: int | None) -> None: ...
def std_variant(arg0: int | float | tuple[int, int]) -> None: ...
def std_vector() -> list[tuple[int, float]]: ...



from __future__ import annotations

import typing

__all__: list[str] = ["Base", "CppException", "Derived", "Foo", "Outer"]

class Base:
    class Inner:
        pass
    name: str

class CppException(Exception):
    pass

class Derived(Base):
    count: int

class Foo:
    class FooChild:
        def __init__(self) -> None: ...
        def g(self) -> None: ...

    def __init__(self) -> None: ...
    def f(self) -> None: ...

class Outer:
    class Inner:
        class NestedEnum:
            """
            Members:

              ONE

              TWO
            """

            ONE: typing.ClassVar[Outer.Inner.NestedEnum]  # value = <NestedEnum.ONE: 1>
            TWO: typing.ClassVar[Outer.Inner.NestedEnum]  # value = <NestedEnum.TWO: 2>
            __members__: typing.ClassVar[
                dict[str, Outer.Inner.NestedEnum]
            ]  # value = {'ONE': <NestedEnum.ONE: 1>, 'TWO': <NestedEnum.TWO: 2>}
            def __eq__(self, other: typing.Any) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __init__(self, value: int) -> None: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: typing.Any) -> bool: ...
            def __repr__(self) -> str: ...
            def __setstate__(self, state: int) -> None: ...
            def __str__(self) -> str: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        value: Outer.Inner.NestedEnum
    inner: Outer.Inner



from __future__ import annotations

import typing

__all__: list[str] = [
    "WithGetterSetterDoc",
    "WithPropAndGetterSetterDoc",
    "WithPropDoc",
    "WithoutDoc",
]

class WithGetterSetterDoc:
    """
    User docstring provided via pybind11::cpp_function(..., doc) to getters/setters, but NOT to `def_*(..., doc)` calls
    """

    def_property_readonly_static: typing.ClassVar[int] = 0
    def_property_static: typing.ClassVar[int] = 0
    @property
    def def_property(self) -> int:
        """
        getter doc token
        """
    @def_property.setter
    def def_property(self, arg1: int) -> None:
        """
        setter doc token
        """
    @property
    def def_property_readonly(self) -> int:
        """
        getter doc token
        """

class WithPropAndGetterSetterDoc:
    """
    User docstring provided via pybind11::cpp_function(..., doc) to getters/setters and to `def_*(, doc)` calls
    """

    def_property_readonly_static: typing.ClassVar[int] = 0
    def_property_static: typing.ClassVar[int] = 0
    @property
    def def_property(self) -> int:
        """
        prop doc token
        """
    @def_property.setter
    def def_property(self, arg1: int) -> None: ...
    @property
    def def_property_readonly(self) -> int:
        """
        prop doc token
        """

class WithPropDoc:
    """
    User docstring provided only to `def_` calls
    """

    def_property_readonly_static: typing.ClassVar[int] = 0
    def_property_static: typing.ClassVar[int] = 0
    @property
    def def_property(self) -> int:
        """
        prop doc token
        """
    @def_property.setter
    def def_property(self, arg1: int) -> None: ...
    @property
    def def_property_readonly(self) -> int:
        """
        prop doc token
        """
    @property
    def def_readonly(self) -> int:
        """
        prop doc token
        """
    @property
    def def_readwrite(self) -> int:
        """
        prop doc token
        """
    @def_readwrite.setter
    def def_readwrite(self, arg0: int) -> None: ...

class WithoutDoc:
    """
    No user docstring provided
    """

    def_property_readonly_static: typing.ClassVar[int] = 0
    def_property_static: typing.ClassVar[int] = 0
    def_property: int
    def_readwrite: int
    @property
    def def_property_readonly(self) -> int: ...
    @property
    def def_readonly(self) -> int: ...



from __future__ import annotations

import typing

import typing_extensions

__all__: list[str] = ["get_buffer", "get_sequence"]

def get_buffer(arg0: typing_extensions.Buffer) -> typing_extensions.Buffer: ...
def get_sequence(arg0: typing.Sequence) -> typing.Sequence: ...



from __future__ import annotations

import typing as typing

__all__: list[str] = ["args_mix", "typing"]

def args_mix(
    a: int,
    b: float = 0.5,
    c: str = "",
    *args: int,
    x: int = 1,
    y=int,
    **kwargs: typing.Dict[int, str],
): ...



from __future__ import annotations

import datetime

import numpy
from numpy import random

__all__: list[str] = [
    "Dummy",
    "Foo",
    "add_day",
    "foolist",
    "foovar",
    "list_with_none",
    "none",
    "random",
    "t_10ms",
    "t_20ns",
    "t_30s",
]

class Dummy:
    linalg = numpy.linalg

class Foo:
    pass

def add_day(arg0: datetime.datetime) -> datetime.datetime: ...

foolist: list  # value = [<demo._bindings.values.Foo object>, <demo._bindings.values.Foo object>]
foovar: Foo  # value = <demo._bindings.values.Foo object>
list_with_none: list = [None, 2, {}]
none = None
t_10ms: datetime.timedelta  # value = datetime.timedelta(microseconds=10000)
t_20ns: datetime.timedelta  # value = datetime.timedelta(0)
t_30s: datetime.timedelta  # value = datetime.timedelta(seconds=30)



from __future__ import annotations

import typing

__all__: list[str] = [
    "MapStringComplex",
    "VectorPairStringDouble",
    "get_complex_map",
    "get_vector_of_pairs",
]

class MapStringComplex:
    def __bool__(self) -> bool:
        """
        Check whether the map is nonempty
        """
    @typing.overload
    def __contains__(self, arg0: str) -> bool: ...
    @typing.overload
    def __contains__(self, arg0: typing.Any) -> bool: ...
    def __delitem__(self, arg0: str) -> None: ...
    def __getitem__(self, arg0: str) -> complex: ...
    def __init__(self) -> None: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __len__(self) -> int: ...
    def __repr__(self) -> str:
        """
        Return the canonical string representation of this map.
        """
    def __setitem__(self, arg0: str, arg1: complex) -> None: ...
    def items(self) -> typing.ItemsView: ...
    def keys(self) -> typing.KeysView: ...
    def values(self) -> typing.ValuesView: ...

class VectorPairStringDouble:
    __hash__: typing.ClassVar[None] = None
    def __bool__(self) -> bool:
        """
        Check whether the list is nonempty
        """
    def __contains__(self, x: tuple[str, float]) -> bool:
        """
        Return true the container contains ``x``
        """
    @typing.overload
    def __delitem__(self, arg0: int) -> None:
        """
        Delete the list elements at index ``i``
        """
    @typing.overload
    def __delitem__(self, arg0: slice) -> None:
        """
        Delete list elements using a slice object
        """
    def __eq__(self, arg0: VectorPairStringDouble) -> bool: ...
    @typing.overload
    def __getitem__(self, s: slice) -> VectorPairStringDouble:
        """
        Retrieve list elements using a slice object
        """
    @typing.overload
    def __getitem__(self, arg0: int) -> tuple[str, float]: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, arg0: VectorPairStringDouble) -> None:
        """
        Copy constructor
        """
    @typing.overload
    def __init__(self, arg0: typing.Iterable) -> None: ...
    def __iter__(self) -> typing.Iterator[tuple[str, float]]: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorPairStringDouble) -> bool: ...
    @typing.overload
    def __setitem__(self, arg0: int, arg1: tuple[str, float]) -> None: ...
    @typing.overload
    def __setitem__(self, arg0: slice, arg1: VectorPairStringDouble) -> None:
        """
        Assign list elements using a slice object
        """
    def append(self, x: tuple[str, float]) -> None:
        """
        Add an item to the end of the list
        """
    def clear(self) -> None:
        """
        Clear the contents
        """
    def count(self, x: tuple[str, float]) -> int:
        """
        Return the number of times ``x`` appears in the list
        """
    @typing.overload
    def extend(self, L: VectorPairStringDouble) -> None:
        """
        Extend the list by appending all the items in the given list
        """
    @typing.overload
    def extend(self, L: typing.Iterable) -> None:
        """
        Extend the list by appending all the items in the given list
        """
    def insert(self, i: int, x: tuple[str, float]) -> None:
        """
        Insert an item at a given position.
        """
    @typing.overload
    def pop(self) -> tuple[str, float]:
        """
        Remove and return the last item
        """
    @typing.overload
    def pop(self, i: int) -> tuple[str, float]:
        """
        Remove and return the item at index ``i``
        """
    def remove(self, x: tuple[str, float]) -> None:
        """
        Remove the first item from the list whose value is x. It is an error if there is no such item.
        """

def get_complex_map() -> MapStringComplex: ...
def get_vector_of_pairs() -> VectorPairStringDouble: ...



from __future__ import annotations

import typing

__all__: list[str] = [
    "Blue",
    "ConsoleForegroundColor",
    "Green",
    "Magenta",
    "None_",
    "Yellow",
    "accept_defaulted_enum",
]

class ConsoleForegroundColor:
    """
    Members:

      Green

      Yellow

      Blue

      Magenta

      None_
    """

    Blue: typing.ClassVar[
        ConsoleForegroundColor
    ]  # value = <ConsoleForegroundColor.Blue: 34>
    Green: typing.ClassVar[
        ConsoleForegroundColor
    ]  # value = <ConsoleForegroundColor.Green: 32>
    Magenta: typing.ClassVar[
        ConsoleForegroundColor
    ]  # value = <ConsoleForegroundColor.Magenta: 35>
    None_: typing.ClassVar[
        ConsoleForegroundColor
    ]  # value = <ConsoleForegroundColor.None_: -1>
    Yellow: typing.ClassVar[
        ConsoleForegroundColor
    ]  # value = <ConsoleForegroundColor.Yellow: 33>
    __members__: typing.ClassVar[
        dict[str, ConsoleForegroundColor]
    ]  # value = {'Green': <ConsoleForegroundColor.Green: 32>, 'Yellow': <ConsoleForegroundColor.Yellow: 33>, 'Blue': <ConsoleForegroundColor.Blue: 34>, 'Magenta': <ConsoleForegroundColor.Magenta: 35>, 'None_': <ConsoleForegroundColor.None_: -1>}
    def __eq__(self, other: typing.Any) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self, value: int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: typing.Any) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self, state: int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

def accept_defaulted_enum(
    color: ConsoleForegroundColor = ConsoleForegroundColor.None_,
) -> None: ...

Blue: ConsoleForegroundColor  # value = <ConsoleForegroundColor.Blue: 34>
Green: ConsoleForegroundColor  # value = <ConsoleForegroundColor.Green: 32>
Magenta: ConsoleForegroundColor  # value = <ConsoleForegroundColor.Magenta: 35>
None_: ConsoleForegroundColor  # value = <ConsoleForegroundColor.None_: -1>
Yellow: ConsoleForegroundColor  # value = <ConsoleForegroundColor.Yellow: 33>



from __future__ import annotations

import typing

import numpy
from numpy import random

import demo._bindings.enum
from demo._bindings.aliases.foreign_method_arg import Bar2 as foreign_type_alias
from demo._bindings.aliases.foreign_return import get_foo as foreign_class_alias

from . import (
    foreign_arg,
    foreign_attr,
    foreign_class_member,
    foreign_method_arg,
    foreign_method_return,
    foreign_return,
    missing_self_arg,
)

__all__: list[str] = [
    "Color",
    "Dummy",
    "foreign_arg",
    "foreign_attr",
    "foreign_class_alias",
    "foreign_class_member",
    "foreign_enum_default",
    "foreign_method_arg",
    "foreign_method_return",
    "foreign_return",
    "foreign_type_alias",
    "func",
    "local_func_alias",
    "local_type_alias",
    "missing_self_arg",
    "random",
]

class Color:
    pass

class Dummy:
    linalg = numpy.linalg

def foreign_enum_default(
    color: typing.Any = demo._bindings.enum.ConsoleForegroundColor.Blue,
) -> None: ...
def func(arg0: int) -> int: ...

local_func_alias = func
local_type_alias = Color



from __future__ import annotations

__all__: list[str] = [
    "Enum",
    "Unbound",
    "accept_unbound_enum",
    "accept_unbound_enum_defaulted",
    "accept_unbound_type",
    "accept_unbound_type_defaulted",
    "get_unbound_type",
]

class Enum:
    pass

class Unbound:
    pass

def accept_unbound_enum(arg0: ...) -> int: ...
def accept_unbound_enum_defaulted(x: Enum = ...) -> int: ...
def accept_unbound_type(arg0: tuple[..., int]) -> int: ...
def accept_unbound_type_defaulted(x: Unbound = ...) -> int: ...
def get_unbound_type() -> ...: ...



from __future__ import annotations

import sys
import typing

if sys.version_info[:2] >= (3, 8):
    from .functions_3_8_plus import args_mix

if sys.version_info[:2] >= (3, 9):
    from .functions_3_9_plus import generic_alias_annotation


class _Dummy:
    @staticmethod
    def foo():
        return 42


def search(a: int, b: list[int]) -> int:
    ...


def builtin_function_as_default_arg(func: type(len) = len):
    ...


def function_as_default_arg(func: type(search) = search):
    ...


def lambda_as_default_arg(callback=lambda val: 0):
    ...


def static_method_as_default_arg(callback=_Dummy.foo):
    ...


def accept_frozenset(arg: typing.FrozenSet[int | float]) -> int | None:
    pass



from __future__ import annotations

import typing

__all__: list[str] = [
    "backslashes_should_be_escaped",
    "issue_51_catastrophic_regex",
    "issue_73_utf8_doc_chars",
]

def backslashes_should_be_escaped() -> None:
    """
    \\brief A brief description of this function.

    A detailed description of this function.

    Here's some reStructuredText: :math:`x = [x, y, \\theta]^T`
    """

def issue_51_catastrophic_regex(arg0: int, arg1: int) -> None:
    """
    Use-case:
        issue_51(os.get_handle_inheritable, os.set_handle_inheritable)
    """

def issue_73_utf8_doc_chars() -> None:
    """
    Construct a Ramsete unicycle controller.

    Tuning parameter (b > 0 rad²/m²) for which larger values make

    convergence more aggressive like a proportional term.
    Tuning parameter (0 rad⁻¹ < zeta < 1 rad⁻¹) for which larger
    values provide more damping in response.
    """

_cleanup: typing.Any  # value = <capsule object>



from __future__ import annotations

import typing

import numpy
import scipy.sparse

__all__: list[str] = [
    "accept_matrix_int",
    "accept_vector_float64",
    "dense_matrix_c",
    "dense_matrix_r",
    "fixed_mutator_a",
    "fixed_mutator_c",
    "fixed_mutator_r",
    "four_col_matrix_r",
    "four_row_matrix_r",
    "get_matrix_int",
    "get_vector_float64",
    "sparse_matrix_c",
    "sparse_matrix_r",
]
M = typing.TypeVar("M", bound=int)
N = typing.TypeVar("N", bound=int)

def accept_matrix_int(
    arg0: numpy.ndarray[
        tuple[typing.Literal[3], typing.Literal[3]], numpy.dtype[numpy.int32]
    ]
) -> None: ...
def accept_vector_float64(
    arg0: numpy.ndarray[
        tuple[typing.Literal[3], typing.Literal[1]], numpy.dtype[numpy.float64]
    ]
) -> None: ...
def dense_matrix_c(
    arg0: numpy.ndarray[tuple[M, N], numpy.dtype[numpy.float32]]
) -> numpy.ndarray[tuple[M, N], numpy.dtype[numpy.float32]]: ...
def dense_matrix_r(
    arg0: numpy.ndarray[tuple[M, N], numpy.dtype[numpy.float32]]
) -> numpy.ndarray[tuple[M, N], numpy.dtype[numpy.float32]]: ...
def fixed_mutator_a(
    arg0: numpy.ndarray[
        tuple[typing.Literal[5], typing.Literal[6]], numpy.dtype[numpy.float32]
    ]
) -> None: ...
def fixed_mutator_c(
    arg0: numpy.ndarray[
        tuple[typing.Literal[5], typing.Literal[6]], numpy.dtype[numpy.float32]
    ]
) -> None: ...
def fixed_mutator_r(
    arg0: numpy.ndarray[
        tuple[typing.Literal[5], typing.Literal[6]], numpy.dtype[numpy.float32]
    ]
) -> None: ...
def four_col_matrix_r(
    arg0: numpy.ndarray[tuple[M, typing.Literal[4]], numpy.dtype[numpy.float32]]
) -> numpy.ndarray[tuple[M, typing.Literal[4]], numpy.dtype[numpy.float32]]: ...
def four_row_matrix_r(
    arg0: numpy.ndarray[tuple[typing.Literal[4], N], numpy.dtype[numpy.float32]]
) -> numpy.ndarray[tuple[typing.Literal[4], N], numpy.dtype[numpy.float32]]: ...
def get_matrix_int() -> numpy.ndarray[
    tuple[typing.Literal[3], typing.Literal[3]], numpy.dtype[numpy.int32]
]: ...
def get_vector_float64() -> numpy.ndarray[
    tuple[typing.Literal[3], typing.Literal[1]], numpy.dtype[numpy.float64]
]: ...
def sparse_matrix_c(arg0: scipy.sparse.csc_matrix) -> scipy.sparse.csc_matrix: ...
def sparse_matrix_r(arg0: scipy.sparse.csr_matrix) -> scipy.sparse.csr_matrix: ...



from __future__ import annotations

from demo._bindings import (
    aliases,
    classes,
    eigen,
    enum,
    flawed_bindings,
    functions,
    issues,
    methods,
    numpy,
    properties,
    stl,
    stl_bind,
    typing,
    values,
)

__all__: list[str] = [
    "aliases",
    "classes",
    "eigen",
    "enum",
    "flawed_bindings",
    "functions",
    "issues",
    "methods",
    "numpy",
    "properties",
    "stl",
    "stl_bind",
    "typing",
    "values",
]



from __future__ import annotations

import typing

import numpy
import pybind11_stubgen.typing_ext
import scipy.sparse

__all__: list[str] = [
    "accept_matrix_int",
    "accept_vector_float64",
    "dense_matrix_c",
    "dense_matrix_r",
    "fixed_mutator_a",
    "fixed_mutator_c",
    "fixed_mutator_r",
    "four_col_matrix_r",
    "four_row_matrix_r",
    "get_matrix_int",
    "get_vector_float64",
    "sparse_matrix_c",
    "sparse_matrix_r",
]

def accept_matrix_int(
    arg0: typing.Annotated[
        numpy.ndarray, numpy.int32, pybind11_stubgen.typing_ext.FixedSize(3, 3)
    ]
) -> None: ...
def accept_vector_float64(
    arg0: typing.Annotated[
        numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)
    ]
) -> None: ...
def dense_matrix_c(
    arg0: typing.Annotated[
        numpy.ndarray, numpy.float32, pybind11_stubgen.typing_ext.DynamicSize("m", "n")
    ]
) -> typing.Annotated[
    numpy.ndarray, numpy.float32, pybind11_stubgen.typing_ext.DynamicSize("m", "n")
]: ...
def dense_matrix_r(
    arg0: typing.Annotated[
        numpy.ndarray, numpy.float32, pybind11_stubgen.typing_ext.DynamicSize("m", "n")
    ]
) -> typing.Annotated[
    numpy.ndarray, numpy.float32, pybind11_stubgen.typing_ext.DynamicSize("m", "n")
]: ...
def fixed_mutator_a(
    arg0: typing.Annotated[
        numpy.ndarray,
        numpy.float32,
        pybind11_stubgen.typing_ext.FixedSize(5, 6),
        numpy.ndarray.flags.writeable,
    ]
) -> None: ...
def fixed_mutator_c(
    arg0: typing.Annotated[
        numpy.ndarray,
        numpy.float32,
        pybind11_stubgen.typing_ext.FixedSize(5, 6),
        numpy.ndarray.flags.writeable,
        numpy.ndarray.flags.f_contiguous,
    ]
) -> None: ...
def fixed_mutator_r(
    arg0: typing.Annotated[
        numpy.ndarray,
        numpy.float32,
        pybind11_stubgen.typing_ext.FixedSize(5, 6),
        numpy.ndarray.flags.writeable,
        numpy.ndarray.flags.c_contiguous,
    ]
) -> None: ...
def four_col_matrix_r(
    arg0: typing.Annotated[
        numpy.ndarray, numpy.float32, pybind11_stubgen.typing_ext.DynamicSize("m", 4)
    ]
) -> typing.Annotated[
    numpy.ndarray, numpy.float32, pybind11_stubgen.typing_ext.DynamicSize("m", 4)
]: ...
def four_row_matrix_r(
    arg0: typing.Annotated[
        numpy.ndarray, numpy.float32, pybind11_stubgen.typing_ext.DynamicSize(4, "n")
    ]
) -> typing.Annotated[
    numpy.ndarray, numpy.float32, pybind11_stubgen.typing_ext.DynamicSize(4, "n")
]: ...
def get_matrix_int() -> typing.Annotated[
    numpy.ndarray, numpy.int32, pybind11_stubgen.typing_ext.FixedSize(3, 3)
]: ...
def get_vector_float64() -> typing.Annotated[
    numpy.ndarray, numpy.float64, pybind11_stubgen.typing_ext.FixedSize(3, 1)
]: ...
def sparse_matrix_c(
    arg0: typing.Annotated[scipy.sparse.csc_matrix, numpy.float32]
) -> typing.Annotated[scipy.sparse.csc_matrix, numpy.float32]: ...
def sparse_matrix_r(
    arg0: typing.Annotated[scipy.sparse.csr_matrix, numpy.float32]
) -> typing.Annotated[scipy.sparse.csr_matrix, numpy.float32]: ...



from __future__ import annotations

import typing

import numpy

__all__: list[str] = [
    "accept_ndarray_float64",
    "accept_ndarray_int",
    "get_ndarray_float64",
    "get_ndarray_int",
    "return_dtype",
]

def accept_ndarray_float64(
    arg0: numpy.ndarray[typing.Any, numpy.dtype[numpy.float64]]
) -> None: ...
def accept_ndarray_int(
    arg0: numpy.ndarray[typing.Any, numpy.dtype[numpy.int32]]
) -> None: ...
def get_ndarray_float64() -> numpy.ndarray[typing.Any, numpy.dtype[numpy.float64]]: ...
def get_ndarray_int() -> numpy.ndarray[typing.Any, numpy.dtype[numpy.int32]]: ...
def return_dtype() -> numpy.dtype[typing.Any]: ...
